package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: Nov 21, 2025
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
设置默认值
从JSON、TOML、YAML、HCL、envfile和Java properties格式的配置文件读取配置信息
实时监控和重新读取配置文件(可选)
从环境变量中读取
从远程配置系统(etcd或Consul)读取并监控配置变化
从命令行参数读取配置
从buffer读取配置
显式配置值
Documentation
¶
Config is a config interface.
New a config with options.
Decoder is config decoder.
KeyValue is config key value.
type Option func(*options)
Option is config option.
WithSource with config source.
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.